Struct ex3_node_types::block::CandidConsensusBlockHead
source · pub struct CandidConsensusBlockHead {
pub head: CandidBlockHead,
pub timestamp: TimeInNs,
}Fields
head: CandidBlockHeadtimestamp: TimeInNsTrait Implementations
sourceimpl Clone for CandidConsensusBlockHead
impl Clone for CandidConsensusBlockHead
sourcefn clone(&self) -> CandidConsensusBlockHead
fn clone(&self) -> CandidConsensusBlockHead
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for CandidConsensusBlockHead
impl Debug for CandidConsensusBlockHead
sourceimpl<'de> Deserialize<'de> for CandidConsensusBlockHead
impl<'de> Deserialize<'de> for CandidConsensusBlockHead
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<CandidConsensusBlockHead> for ConsensusBlockHead
impl From<CandidConsensusBlockHead> for ConsensusBlockHead
sourcefn from(candid_consensus_block_head: CandidConsensusBlockHead) -> Self
fn from(candid_consensus_block_head: CandidConsensusBlockHead) -> Self
Converts to this type from the input type.
sourceimpl From<ConsensusBlockHead> for CandidConsensusBlockHead
impl From<ConsensusBlockHead> for CandidConsensusBlockHead
sourcefn from(consensus_block_head: ConsensusBlockHead) -> Self
fn from(consensus_block_head: ConsensusBlockHead) -> Self
Converts to this type from the input type.
sourceimpl Ord for CandidConsensusBlockHead
impl Ord for CandidConsensusBlockHead
sourcefn cmp(&self, other: &CandidConsensusBlockHead) -> Ordering
fn cmp(&self, other: &CandidConsensusBlockHead) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for CandidConsensusBlockHead
impl PartialEq for CandidConsensusBlockHead
sourcefn eq(&self, other: &CandidConsensusBlockHead) -> bool
fn eq(&self, other: &CandidConsensusBlockHead) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for CandidConsensusBlockHead
impl PartialOrd for CandidConsensusBlockHead
sourcefn partial_cmp(&self, other: &CandidConsensusBlockHead) -> Option<Ordering>
fn partial_cmp(&self, other: &CandidConsensusBlockHead) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for CandidConsensusBlockHead
impl StructuralEq for CandidConsensusBlockHead
impl StructuralPartialEq for CandidConsensusBlockHead