Struct ex3_node_types::chain::ChainIdentifier
source · pub struct ChainIdentifier {
pub chain: Chain,
pub network: u8,
}Fields
chain: Chainnetwork: u8Trait Implementations
sourceimpl CandidType for ChainIdentifier
impl CandidType for ChainIdentifier
sourceimpl Clone for ChainIdentifier
impl Clone for ChainIdentifier
sourcefn clone(&self) -> ChainIdentifier
fn clone(&self) -> ChainIdentifier
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ChainIdentifier
impl Debug for ChainIdentifier
sourceimpl<'de> Deserialize<'de> for ChainIdentifier
impl<'de> Deserialize<'de> for ChainIdentifier
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for ChainIdentifier
impl Hash for ChainIdentifier
sourceimpl Ord for ChainIdentifier
impl Ord for ChainIdentifier
sourceimpl PartialEq for ChainIdentifier
impl PartialEq for ChainIdentifier
sourcefn eq(&self, other: &ChainIdentifier) -> bool
fn eq(&self, other: &ChainIdentifier) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ChainIdentifier
impl PartialOrd for ChainIdentifier
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for ChainIdentifier
impl Serialize for ChainIdentifier
sourceimpl Storable for ChainIdentifier
impl Storable for ChainIdentifier
sourcefn from_bytes(bytes: Cow<'_, [u8]>) -> Self
fn from_bytes(bytes: Cow<'_, [u8]>) -> Self
Converts bytes into an element.
sourcefn to_bytes_checked(&self) -> Cow<'_, [u8]>
fn to_bytes_checked(&self) -> Cow<'_, [u8]>
Like
to_bytes, but includes additional checks to ensure the element’s serialized bytes
are within the element’s bounds.impl Eq for ChainIdentifier
impl StructuralEq for ChainIdentifier
impl StructuralPartialEq for ChainIdentifier