pub enum SwapV2ExactTokens {
ExactInput {
amount: AssetAmount,
min_out: AssetAmount,
},
ExactOutput {
amount: AssetAmount,
max_in: AssetAmount,
},
}Expand description
SwapV2 exact tokens
Variants
ExactInput
Fields

amount: AssetAmountInput amount Note: input amount means the input asset quantity

min_out: AssetAmountMin out Note: min out means the output asset quantity must be greater than or equal to the min out
Exact input
ExactOutput
Fields

amount: AssetAmountOutput amount Note: output amount means the output asset quantity

max_in: AssetAmountMax in Note: max in means the input asset quantity must be less than or equal to the max in
Exact output