pub struct CandidConfirmedDeposit {
pub seq_id: CandidDepositId,
pub deposit: CandidDeposit,
pub confirmed_at: TimeInNs,
}Expand description
CandidConfirmedDeposit
Fields
seq_id: CandidDepositIddeposit: CandidDepositconfirmed_at: TimeInNsTrait Implementations
sourceimpl CandidType for CandidConfirmedDeposit
impl CandidType for CandidConfirmedDeposit
sourceimpl Clone for CandidConfirmedDeposit
impl Clone for CandidConfirmedDeposit
sourcefn clone(&self) -> CandidConfirmedDeposit
fn clone(&self) -> CandidConfirmedDeposit
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for CandidConfirmedDeposit
impl Debug for CandidConfirmedDeposit
sourceimpl<'de> Deserialize<'de> for CandidConfirmedDeposit
impl<'de> Deserialize<'de> for CandidConfirmedDeposit
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<CandidConfirmedDeposit> for ConfirmedDeposit
impl From<CandidConfirmedDeposit> for ConfirmedDeposit
sourcefn from(deposit: CandidConfirmedDeposit) -> Self
fn from(deposit: CandidConfirmedDeposit) -> Self
Converts to this type from the input type.
sourceimpl From<ConfirmedDeposit> for CandidConfirmedDeposit
impl From<ConfirmedDeposit> for CandidConfirmedDeposit
sourcefn from(deposit: ConfirmedDeposit) -> Self
fn from(deposit: ConfirmedDeposit) -> Self
Converts to this type from the input type.
sourceimpl Hash for CandidConfirmedDeposit
impl Hash for CandidConfirmedDeposit
sourceimpl Ord for CandidConfirmedDeposit
impl Ord for CandidConfirmedDeposit
sourcefn cmp(&self, other: &CandidConfirmedDeposit) -> Ordering
fn cmp(&self, other: &CandidConfirmedDeposit) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for CandidConfirmedDeposit
impl PartialEq for CandidConfirmedDeposit
sourcefn eq(&self, other: &CandidConfirmedDeposit) -> bool
fn eq(&self, other: &CandidConfirmedDeposit) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for CandidConfirmedDeposit
impl PartialOrd for CandidConfirmedDeposit
sourcefn partial_cmp(&self, other: &CandidConfirmedDeposit) -> Option<Ordering>
fn partial_cmp(&self, other: &CandidConfirmedDeposit) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for CandidConfirmedDeposit
impl StructuralEq for CandidConfirmedDeposit
impl StructuralPartialEq for CandidConfirmedDeposit