Struct ex3_node_types::transaction::CandidDeposit
source · pub struct CandidDeposit {
pub identifier: CandidDepositIdentifier,
pub from_wallet: CandidWalletRegisterId,
pub amount: CandidAssetAmount,
}Expand description
Deposit
Fields
identifier: CandidDepositIdentifierfrom_wallet: CandidWalletRegisterIdamount: CandidAssetAmountTrait Implementations
sourceimpl CandidType for CandidDeposit
impl CandidType for CandidDeposit
sourceimpl Clone for CandidDeposit
impl Clone for CandidDeposit
sourcefn clone(&self) -> CandidDeposit
fn clone(&self) -> CandidDeposit
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for CandidDeposit
impl Debug for CandidDeposit
sourceimpl<'de> Deserialize<'de> for CandidDeposit
impl<'de> Deserialize<'de> for CandidDeposit
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<CandidDeposit> for Deposit
impl From<CandidDeposit> for Deposit
sourcefn from(deposit: CandidDeposit) -> Self
fn from(deposit: CandidDeposit) -> Self
Converts to this type from the input type.
sourceimpl From<Deposit> for CandidDeposit
impl From<Deposit> for CandidDeposit
sourceimpl Hash for CandidDeposit
impl Hash for CandidDeposit
sourceimpl Ord for CandidDeposit
impl Ord for CandidDeposit
sourcefn cmp(&self, other: &CandidDeposit) -> Ordering
fn cmp(&self, other: &CandidDeposit) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for CandidDeposit
impl PartialEq for CandidDeposit
sourcefn eq(&self, other: &CandidDeposit) -> bool
fn eq(&self, other: &CandidDeposit) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for CandidDeposit
impl PartialOrd for CandidDeposit
sourcefn partial_cmp(&self, other: &CandidDeposit) -> Option<Ordering>
fn partial_cmp(&self, other: &CandidDeposit) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for CandidDeposit
impl StructuralPartialEq for CandidDeposit