Struct ex3_node_types::transaction::ConfirmedDeposit
source · pub struct ConfirmedDeposit {
pub seq_id: DepositId,
pub deposit: Deposit,
pub confirmed_at: TimeInNs,
}Expand description
ConfirmedDeposit
Fields
seq_id: DepositIddeposit: Depositconfirmed_at: TimeInNsTrait Implementations
sourceimpl Clone for ConfirmedDeposit
impl Clone for ConfirmedDeposit
sourcefn clone(&self) -> ConfirmedDeposit
fn clone(&self) -> ConfirmedDeposit
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ConfirmedDeposit
impl Debug for ConfirmedDeposit
sourceimpl<'de> Deserialize<'de> for ConfirmedDeposit
impl<'de> Deserialize<'de> for ConfirmedDeposit
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<CandidConfirmedDeposit> for ConfirmedDeposit
impl From<CandidConfirmedDeposit> for ConfirmedDeposit
sourcefn from(deposit: CandidConfirmedDeposit) -> Self
fn from(deposit: CandidConfirmedDeposit) -> Self
Converts to this type from the input type.
sourceimpl From<ConfirmedDeposit> for CandidConfirmedDeposit
impl From<ConfirmedDeposit> for CandidConfirmedDeposit
sourcefn from(deposit: ConfirmedDeposit) -> Self
fn from(deposit: ConfirmedDeposit) -> Self
Converts to this type from the input type.
sourceimpl Hash for ConfirmedDeposit
impl Hash for ConfirmedDeposit
sourceimpl Ord for ConfirmedDeposit
impl Ord for ConfirmedDeposit
sourcefn cmp(&self, other: &ConfirmedDeposit) -> Ordering
fn cmp(&self, other: &ConfirmedDeposit) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for ConfirmedDeposit
impl PartialEq for ConfirmedDeposit
sourcefn eq(&self, other: &ConfirmedDeposit) -> bool
fn eq(&self, other: &ConfirmedDeposit) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ConfirmedDeposit
impl PartialOrd for ConfirmedDeposit
sourcefn partial_cmp(&self, other: &ConfirmedDeposit) -> Option<Ordering>
fn partial_cmp(&self, other: &ConfirmedDeposit) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for ConfirmedDeposit
impl Serialize for ConfirmedDeposit
sourceimpl Storable for ConfirmedDeposit
impl Storable for ConfirmedDeposit
sourcefn from_bytes(bytes: Cow<'_, [u8]>) -> Self
fn from_bytes(bytes: Cow<'_, [u8]>) -> Self
Converts bytes into an element.
sourcefn to_bytes_checked(&self) -> Cow<'_, [u8]>
fn to_bytes_checked(&self) -> Cow<'_, [u8]>
Like
to_bytes, but includes additional checks to ensure the element’s serialized bytes
are within the element’s bounds.impl Eq for ConfirmedDeposit
impl StructuralEq for ConfirmedDeposit
impl StructuralPartialEq for ConfirmedDeposit