Struct ex3_node_types::transaction::Deposit
source · pub struct Deposit {
pub identifier: DepositIdentifier,
pub from_wallet: WalletRegisterId,
pub amount: AssetAmount,
}Expand description
Deposit
Fields
identifier: DepositIdentifierfrom_wallet: WalletRegisterIdamount: AssetAmountTrait Implementations
sourceimpl<'de> Deserialize<'de> for Deposit
impl<'de> Deserialize<'de> for Deposit
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<CandidDeposit> for Deposit
impl From<CandidDeposit> for Deposit
sourcefn from(deposit: CandidDeposit) -> Self
fn from(deposit: CandidDeposit) -> Self
Converts to this type from the input type.
sourceimpl From<Deposit> for CandidDeposit
impl From<Deposit> for CandidDeposit
sourceimpl Ord for Deposit
impl Ord for Deposit
sourceimpl PartialEq for Deposit
impl PartialEq for Deposit
sourceimpl PartialOrd for Deposit
impl PartialOrd for Deposit
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Storable for Deposit
impl Storable for Deposit
sourcefn from_bytes(bytes: Cow<'_, [u8]>) -> Self
fn from_bytes(bytes: Cow<'_, [u8]>) -> Self
Converts bytes into an element.
sourcefn to_bytes_checked(&self) -> Cow<'_, [u8]>
fn to_bytes_checked(&self) -> Cow<'_, [u8]>
Like
to_bytes, but includes additional checks to ensure the element’s serialized bytes
are within the element’s bounds.impl Eq for Deposit
impl StructuralEq for Deposit
impl StructuralPartialEq for Deposit