pub struct Transaction {
    pub version: Version,
    pub type: TransactionType,
    pub from: WalletRegisterId,
    pub nonce: Nonce,
    pub payload: ByteBuf,
    pub signature: ByteBuf,
}

Fields

version: Versiontype: TransactionTypefrom: WalletRegisterIdnonce: Nonce

Nonce is a number that is used only once for every transaction per wallet. If the transaction type is Deposit, Wallet Register, or Reset Main Secret, this field is 0. Otherwise, this field starts from 1.

payload: ByteBufsignature: ByteBuf

Implementations

source

impl Transaction

source

pub fn hash(&self) -> TransactionHash

source

pub fn tx_data_bytes(&self) -> Vec<u8>

source

pub fn encode(&self) -> Vec<u8>

source

pub fn decode(bytes: &[u8]) -> Result<Self, OtherError>