Type Alias ex3_node_types::BlockHeight
source · pub type BlockHeight = Ex3Uint;Aliased Type
struct BlockHeight(pub BigUint);Fields
0: BigUintTrait Implementations
sourceimpl AddAssign<Ex3Uint> for Ex3Uint
impl AddAssign<Ex3Uint> for Ex3Uint
sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moresourceimpl CheckedAdd for Ex3Uint
impl CheckedAdd for Ex3Uint
sourcefn checked_add(&self, rhs: &Self) -> Option<Self>
fn checked_add(&self, rhs: &Self) -> Option<Self>
Adds two numbers, checking for overflow. If overflow happens,
None is
returned.sourceimpl CheckedDiv for Ex3Uint
impl CheckedDiv for Ex3Uint
sourcefn checked_div(&self, rhs: &Self) -> Option<Self>
fn checked_div(&self, rhs: &Self) -> Option<Self>
Divides two numbers, checking for underflow, overflow and division by
zero. If any of that happens,
None is returned.sourceimpl CheckedMul for Ex3Uint
impl CheckedMul for Ex3Uint
sourcefn checked_mul(&self, rhs: &Self) -> Option<Self>
fn checked_mul(&self, rhs: &Self) -> Option<Self>
Multiplies two numbers, checking for underflow or overflow. If underflow
or overflow happens,
None is returned.sourceimpl CheckedSub for Ex3Uint
impl CheckedSub for Ex3Uint
sourcefn checked_sub(&self, rhs: &Self) -> Option<Self>
fn checked_sub(&self, rhs: &Self) -> Option<Self>
Subtracts two numbers, checking for underflow. If underflow happens,
None is returned.sourceimpl<'de> Deserialize<'de> for Ex3Uint
impl<'de> Deserialize<'de> for Ex3Uint
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl DivAssign<Ex3Uint> for Ex3Uint
impl DivAssign<Ex3Uint> for Ex3Uint
sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
Performs the
/= operation. Read moresourceimpl MulAssign<Ex3Uint> for Ex3Uint
impl MulAssign<Ex3Uint> for Ex3Uint
sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Performs the
*= operation. Read moresourceimpl Ord for Ex3Uint
impl Ord for Ex3Uint
sourceimpl PartialEq<Ex3Uint> for Ex3Uint
impl PartialEq<Ex3Uint> for Ex3Uint
sourceimpl PartialOrd<Ex3Uint> for Ex3Uint
impl PartialOrd<Ex3Uint> for Ex3Uint
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl RemAssign<Ex3Uint> for Ex3Uint
impl RemAssign<Ex3Uint> for Ex3Uint
sourcefn rem_assign(&mut self, rhs: Self)
fn rem_assign(&mut self, rhs: Self)
Performs the
%= operation. Read moresourceimpl Storable for Ex3Uint
impl Storable for Ex3Uint
sourcefn from_bytes(bytes: Cow<'_, [u8]>) -> Self
fn from_bytes(bytes: Cow<'_, [u8]>) -> Self
Converts bytes into an element.
sourcefn to_bytes_checked(&self) -> Cow<'_, [u8]>
fn to_bytes_checked(&self) -> Cow<'_, [u8]>
Like
to_bytes, but includes additional checks to ensure the element’s serialized bytes
are within the element’s bounds.sourceimpl SubAssign<Ex3Uint> for Ex3Uint
impl SubAssign<Ex3Uint> for Ex3Uint
sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read more